@@ -28,8 +28,10 @@ import gym
 import orjson
 from gym.wrappers import TimeLimit
 
-from gym_saturation.envs import SaturationEnv
-from gym_saturation.envs.saturation_env import STATE_DIFF_UPDATED
+from gym_saturation.envs.saturation_env import (
+    STATE_DIFF_UPDATED,
+    SaturationEnv,
+)
 from gym_saturation.logic_ops.utils import (
     WrongRefutationProofError,
     clause_length,
@@ -367,4 +369,4 @@ def test_agent(args: Optional[List[str]] = None) -> None:
 
 
 if __name__ == "__main__":
-    test_agent()
+    test_agent()  # pragma: no cover
