@@ -23,9 +23,10 @@ from typing import Any, Dict, List, Optional, Set, Tuple
 import numpy as np
 import orjson
 from gym import Env, spaces
+from tptp_lark_parser.grammar import Clause
+from tptp_lark_parser.tptp_parser import TPTPParser
 
 from gym_saturation.clause_space import ClauseSpace
-from gym_saturation.grammar import Clause
 from gym_saturation.logic_ops.factoring import all_possible_factors
 from gym_saturation.logic_ops.paramodulation import all_paramodulants_from_list
 from gym_saturation.logic_ops.reflexivity_resolution import (
@@ -37,7 +38,6 @@ from gym_saturation.logic_ops.utils import (
     reduce_to_proof,
     reindex_variables,
 )
-from gym_saturation.parsing.tptp_parser import TPTPParser
 
 STATE_DIFF_UPDATED = "state_diff_updated"
 POSITIVE_ACTIONS = "positive_actions"
@@ -250,15 +250,14 @@ class SaturationEnv(Env):
 
     def _max_clauses_result(
         self,
-        reward: float,
         done: bool,
         info: Dict[str, Any],
-    ) -> Tuple[float, bool, Dict[str, Any]]:
+    ) -> Tuple[bool, Dict[str, Any]]:
         if not done:
             if len(self._state) > self.action_space.n:
                 info.pop(STATE_DIFF_UPDATED)
-                return reward, True, info
-        return reward, done, info
+                return True, info
+        return done, info
 
     def step(self, action: int) -> Tuple[dict, float, bool, Dict[str, Any]]:
         if list(self._state.values())[action].processed:
@@ -273,7 +272,7 @@ class SaturationEnv(Env):
                 for clause in self._state.values()
             ]
         )
-        reward, done, info = self._max_clauses_result(reward, done, info)
+        done, info = self._max_clauses_result(done, info)
         return self.state, reward, done, info
 
     @property
