@@ -1,11 +1,11 @@
 # Copyright 2021-2022 Boris Shminke
-
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-
+#
 #     https://www.apache.org/licenses/LICENSE-2.0
-
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -17,7 +17,8 @@ Unification
 """
 from typing import Optional, Tuple
 
-from gym_saturation.grammar import Function, Predicate, Proposition, Variable
+from tptp_lark_parser.grammar import Function, Predicate, Proposition, Variable
+
 from gym_saturation.logic_ops.substitution import Substitution
 from gym_saturation.logic_ops.utils import is_subproposition
 
