@@ -17,9 +17,9 @@ Logic Operations Utils
 """
 import dataclasses
 from itertools import chain
-from typing import Dict, List, Tuple, Union
+from typing import Dict, Tuple, Union
 
-from gym_saturation.grammar import (
+from tptp_lark_parser.grammar import (
     Clause,
     Function,
     Predicate,
@@ -27,6 +27,7 @@ from gym_saturation.grammar import (
     Term,
     Variable,
 )
+
 from gym_saturation.logic_ops.substitution import Substitution
 
 
@@ -59,7 +60,7 @@ def get_variable_list(
     """
     find all variables present in a clause
 
-    >>> from gym_saturation.grammar import Literal
+    >>> from tptp_lark_parser.grammar import Literal
     >>> get_variable_list(Clause((Literal(False, Predicate("this_is_a_test_case", (Function("f", (Variable("X"), Variable("X"))),))),)))
     (Variable(name='X'), Variable(name='X'))
 
@@ -110,7 +111,7 @@ def is_tautology(clause: Clause) -> bool:
     check whether there are two literals, one negated and the other not, with
     the same atom
 
-    >>> from gym_saturation.grammar import Literal
+    >>> from tptp_lark_parser.grammar import Literal
     >>> is_tautology(Clause((Literal(False, Predicate("this_is_a_test_case", ())),)))
     False
     >>> is_tautology(Clause((Literal(False, Predicate("this_is_a_test_case", ())), Literal(True, Predicate("this_is_a_test_case", ())))))
@@ -144,7 +145,7 @@ def clause_length(clause: dict) -> int:
     :param clause: a clause in JSON representation
     :return: sctructural length of a clause
 
-    >>> from gym_saturation.grammar import Literal
+    >>> from tptp_lark_parser.grammar import Literal
     >>> import orjson
     >>> clause_length(orjson.loads(orjson.dumps(
     ...     Clause((Literal(True, Predicate("p", (Function("this_is_a_test_case", ()),))),))
@@ -300,11 +301,11 @@ def replace_subterm_by_index(
     raise NoSubtermFound(subterm_length)
 
 
-def _flat_list(list_of_lists: List[List[str]]) -> List[str]:
-    return list(reversed(sorted(list(set(chain(*list_of_lists))))))
+def _flat_list(list_of_lists: Tuple[Tuple[str, ...], ...]) -> Tuple[str, ...]:
+    return tuple(reversed(sorted(tuple(set(chain(*list_of_lists))))))
 
 
-def reduce_to_proof(clauses: Dict[str, Clause]) -> List[Clause]:
+def reduce_to_proof(clauses: Dict[str, Clause]) -> Tuple[Clause, ...]:
     """
     leave only clauses belonging to the refutational proof
 
@@ -315,34 +316,34 @@ def reduce_to_proof(clauses: Dict[str, Clause]) -> List[Clause]:
      ...
     gym_saturation.logic_ops.utils.WrongRefutationProofError
     >>> state = {"one": Clause((), label="one")}
-    >>> reduce_to_proof(state) == [Clause((), label="one")]
+    >>> reduce_to_proof(state) == (Clause((), label="one"), )
     True
 
     :param clauses: a map of clause labels to clauses
     :returns: the reduced list of clauses
     """
-    empty_clauses = [
+    empty_clauses = tuple(
         clause for clause in clauses.values() if clause.literals == tuple()
-    ]
+    )
     if len(empty_clauses) == 1:
-        reduced = []
-        new_reduced = [empty_clauses[0]]
+        reduced: Tuple[Clause, ...] = ()
+        new_reduced: Tuple[Clause, ...] = (empty_clauses[0],)
         while len(new_reduced) > 0:
-            reduced += [
+            reduced += tuple(
                 clause for clause in new_reduced if clause not in reduced
-            ]
-            new_reduced = [
+            )
+            new_reduced = tuple(
                 clauses[label]
                 for label in _flat_list(
-                    [
+                    tuple(
                         (
-                            []
+                            ()
                             if clause.inference_parents is None
-                            else list(clause.inference_parents)
+                            else clause.inference_parents
                         )
                         for clause in new_reduced
-                    ]
+                    )
                 )
-            ]
+            )
         return reduced
     raise WrongRefutationProofError
