@@ -41,8 +41,12 @@ class VampireWrapper:
     Traceback (most recent call last):
      ...
     ValueError: start solving a problem first!
-    >>> vampire.start(tptp_problem, tptp_folder)  # doctest: +ELLIPSIS
+    >>> old_result = vampire.start(tptp_problem, tptp_folder)
+    >>> print(old_result)  # doctest: +ELLIPSIS
     (('input', '1', 'mortal(X0) | ~man(X0) [input]'),...
+    >>> new_result = vampire.start(tptp_problem, tptp_folder)
+    >>> old_result == new_result
+    True
     >>> vampire.pick_a_clause("wrong")  # doctest: +ELLIPSIS
     Traceback (most recent call last):
      ...
@@ -59,9 +63,10 @@ class VampireWrapper:
         result: Tuple[Tuple[str, str, str], ...] = ()
         self.proc.expect(["Pick a clause:", pexpect.EOF])
         for line in self.proc.before.decode("utf-8").split("\r\n"):
-            if line[:5] == "[SA] " or line[:12] in (
-                "[PP] final: ",
-                "[PP] input: ",
+            if (
+                line[:5] == "[SA] "
+                or line[:12] in ("[PP] final: ", "[PP] input: ")
+                or "[PP] fn def discovered: " in line
             ):
                 result_type, result_body = line[5:].split(": ")
                 clause_label, clause = result_body.split(". ")
@@ -81,6 +86,8 @@ class VampireWrapper:
         :param tptp_folder: the root folder for TPTP library
         :returns: a sequence of action type, clause number and clause
         """
+        if self._proc is not None:
+            self._proc.close()
         self._proc = pexpect.spawn(
             f"{self.binary_path} --manual_cs on --show_everything on "
             + "--time_limit 1D --avatar off "
